Properties Methods Events Direct Link

# Class Ext.ux.data.PagingMemoryProxy

Package: | Ext.ux.data
Defined In: | PagingMemoryProxy.js
Class: | PagingMemoryProxy
Extends: | Object

Paging Memory Proxy, allows to use paging grid with in memory dataset

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.